package com.xy.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 设备流量卡
 * </p>
 *
 * @author lijin
 * @since 2023-10-16
 */
public class DeviceSimDto {

    @Data
    @Accessors(chain = true)
    public static class Pay {

        @NotBlank(message = "orderId不能为空")
        @ApiModelProperty("订单号")
        private String orderId;

        @NotNull(message = "mercId不能为空")
        @ApiModelProperty(value = "商户id")
        private Long mercId;

        @NotEmpty(message = "deviceSimCharges不能为空")
        @ApiModelProperty("续费信息")
        private List<DeviceSimCharge> deviceSimCharges;

        @NotNull(message = "payType不能为空")
        @ApiModelProperty(value = "支付类型 2=支付宝 3=微信 100=赠送")
        private Integer payType;

        @ApiModelProperty(value = "备注")
        private String note;

        @Data
        @Accessors(chain = true)
        public static class DeviceSimCharge {

            @ApiModelProperty("流量卡id")
            private String simId;

            @ApiModelProperty("购买数/赠送数 单位：年/天")
            private Integer size;

            @ApiModelProperty("金额")
            private Integer money;
        }
    }

    @Data
    @Accessors(chain = true)
    public static class PayNotice {

        @NotBlank(message = "orderId不能为空")
        private String orderId;

    }

    @Data
    @Accessors(chain = true)
    public static class Vo {

        @ApiModelProperty(value = "id")
        private String id;

        @ApiModelProperty(value = "类型")
        private Integer type;

        @ApiModelProperty(value = "激活时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime activateTime;

        @ApiModelProperty(value = "过期时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime timeout;

        @ApiModelProperty(value = "最后续费时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime lastRenewalTime;

        @ApiModelProperty(value = "创建时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime createTime;

        @ApiModelProperty(value = "更新时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime updateTime;


    }

}
